@@ -36,7 +36,10 @@ class VialRequestHandler(wsgiref.simple_server.WSGIRequestHandler):
 
 class Vial():
     def __init__(self, app_name="Vial", logger=None):
-        self.response = VResponse()
+        self.headers = {
+                "Server" : app_name
+            }
+        self.response = VResponse(self)
         self.app_name = app_name
         self._logger = logger
 
@@ -67,9 +70,13 @@ class Vial():
             else:
                 self.logger.error(f"Unhandled exception")
                 self.logger.debug(format_traceback())
-            status, headers, body = self.responsei(500)
+            status, headers, body = self.response(500)
 
         respond(status, headers)
+        if request.method == "HEAD":
+            yield b""
+            return
+
         if inspect.isgeneratorfunction(body):
             yield from body
         else:
